- Overview
- Requirements
- Installation
- Post-installation
- Cluster administration
- Monitoring and alerting
- Migration and upgrade
- Product-specific configuration
- Best practices and maintenance
- Troubleshooting
- How to Troubleshoot Services During Installation
- How to Uninstall the Cluster
- How to clean up offline artifacts to improve disk space
- How to disable TLS 1.0 and 1.1
- How to enable Istio logging
- How to manually clean up logs
- How to clean up old logs stored in the sf-logs bucket
- How to debug failed Automation Suite installations
- How to disable TX checksum offloading
- Unable to run an offline installation on RHEL 8.4 OS
- Error in Downloading the Bundle
- Offline installation fails because of missing binary
- Certificate issue in offline installation
- SQL connection string validation error
- Failure After Certificate Update
- Automation Suite Requires Backlog_wait_time to Be Set 1
- Cannot Log in After Migration
- Setting a timeout interval for the management portals
- Update the underlying directory connections
- Kinit: Cannot Find KDC for Realm <AD Domain> While Getting Initial Credentials
- Kinit: Keytab Contains No Suitable Keys for *** While Getting Initial Credentials
- GSSAPI Operation Failed With Error: An Invalid Status Code Was Supplied (Client's Credentials Have Been Revoked).
- Login Failed for User <ADDOMAIN><aduser>. Reason: The Account Is Disabled.
- Alarm Received for Failed Kerberos-tgt-update Job
- SSPI Provider: Server Not Found in Kerberos Database
- Failure to get the sandbox image
- Pods not showing in ArgoCD UI
- Redis Probe Failure
- RKE2 Server Fails to Start
- Secret Not Found in UiPath Namespace
- ArgoCD goes into progressing state after first installation
- Unexpected Inconsistency; Run Fsck Manually
- Missing Self-heal-operator and Sf-k8-utils Repo
- Degraded MongoDB or Business Applications After Cluster Restore
- Unhealthy Services After Cluster Restore or Rollback
- Using the Automation Suite Diagnostics Tool
- Using the Automation Suite support bundle
- Exploring Logs
Install-uipath.sh Parameters
The install-uipath.sh manual installer allows you to customize the installation experience without running the interactive installer (installUiPathAS.sh).
While the manual installer is suitable for advanced scenario, the deployment templates and the interactive installer are still the recommended options.
The install-uipath.sh installer is available in sf-installer.zip. For download instructions, see Downloading installation packages.
Required parameters
--input -i <string>
Specify the input .json file.
input.json refers to the cluster_config.json that defines the parameters, settings, and preferences applied to the UiPath® services deployed via Automation Suite. You need to update this file to change the defaults and use any advanced configuration for your cluster. For details, refer to Manual: Advanced installation experience.
--output -o <string>
Specify the output .json file.
output.json refers to the output file of the manual installer.
Optional Parameters
--install-kubernetes -k
Install the Kubernetes cluster.
--join-node -j <server|agent>
Used only with -k. Determines the type of node to be joined to an existing cluster. Allowed values: <server|agent>.
--install-fabric -f
Install the fabric components.
--install-services -s
Install the UiPath services.
--install-all -a
Run all installers in order. If no installation is explicitly selected, –install-all will be implied.
--install-type <online|offline>
Specify the installation type. Defaults to online. You cannot set it to online together with –offline-bundle.
--offline-bundle <string>
Specify the path to the offline bundle. Indicates that the installation method is tarball.
--offline-tmp-folder <string>
Optional flag that can be used with --offline-bundle or --optional-offline-bundle. Specify the parent directory for the temporary offline installation folder. Defaults to /tmp.
--optional-offline-bundle <string>
Specify the path to the optional offline bundle.
--pre-reqs -p
Check prerequisites. When using this flag, no other flags can be passed.
--install-offline-prereqs
Used with the tarball installation method, performs the installation of all prerequisites.
--skip-packages-install
Skips the installation of prerequisites during the online installation method. By default, prerequisites are installed.
--upgrade -u
Upgrade an existing Automation Suite cluster.
--kubeconfig <string>
Specify path to the kubeconfig file. When this flag is missing, it defaults to /etc/rancher/rke2/rke2.yaml.
--backup -b
Back up the cluster.
--restore -r
Restore the cluster.
--restore-volume
Restore volume.
--disable-backup
Disable the backup.
-d
Run in debug mode.
-h
Display help.
--accept-license-agreement
Mandatory flag to accept the license agreement.
--skip-pre-reqs
Skip prerequisite checks during installation.
--install-standalone-aicenter
Install standalone AI Center service only.
--one-time-manual-backup
Trigger manual backup and disable it after completion.
Examples
-
Install the Kubernetes cluster components on the VM where it is executed, using the online installation method.
install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement -
Install the Kubernetes components on the VM where it is executed, and join it to the existing cluster as a server, using the online installation method.
install-uipath.sh -i ./input.json -o ./output.json -k -j server --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -k -j server --accept-license-agreement -
Perform the complete installation on the current VM, using the online installation method. Includes the Kubernetes cluster components, the Fabric, and the Uipath services.
install-uipath.sh -i ./input.json -o ./output.json -a --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -a --accept-license-agreement -
Perform the complete installation on the current VM, using the online installation method. This time, skip the prerequisites installation.
install-uipath.sh -i ./input.json -o ./output.json -a --skip-packages-install --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -a --skip-packages-install --accept-license-agreement -
Perform the Kubernetes cluster installation, using the tarball installation method. Also, join the node to the existing cluster and install all the offline prerequisites.
install-uipath.sh -i ./input.json -o ./output.json -k -j agent --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreement --install-offline-prereqsinstall-uipath.sh -i ./input.json -o ./output.json -k -j agent --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreement --install-offline-prereqs -
Install the fabric and services components using the offline installation method, without a temporary folder provided.
install-uipath.sh -i ./input.json -o ./output.json -f -s --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json -f -s --offline-bundle "/tmp/sf-infra.tar.gz" --accept-license-agreement -
Execute the installer for an offline installation, but without loading the artifacts.
install-uipath.sh -i ./input.json -o ./output.json --install-type offline -s --accept-license-agreementinstall-uipath.sh -i ./input.json -o ./output.json --install-type offline -s --accept-license-agreement -
Execute the installer skipping the prerequisites check
install-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement --skip-pre-reqsinstall-uipath.sh -i ./input.json -o ./output.json -k --accept-license-agreement --skip-pre-reqs
- Required parameters
--input -i <string>--output -o <string>- Optional Parameters
--install-kubernetes -k--join-node -j <server|agent>--install-fabric -f--install-services -s--install-all -a--install-type <online|offline>--offline-bundle <string>--offline-tmp-folder <string>--optional-offline-bundle <string>--pre-reqs -p--install-offline-prereqs--skip-packages-install--upgrade -u--kubeconfig <string>--backup -b--restore -r--restore-volume--disable-backup-d-h--accept-license-agreement--skip-pre-reqs--install-standalone-aicenter--one-time-manual-backup- Examples